==> depthai_gate-0.0.17-py3-none-any.whl: depthai_gate/discovery.py <==
import socket
import threading
import time
import struct
import logging
from enum import Enum

DEFAULT_DEVICE_DISCOVERY_PORT = 11491

# struct ResponseDeviceDiscovery : Response {
#     ResponseDeviceDiscovery() : Response(Command::DEVICE_DISCOVERY) {}
#     char mxid[32] = {0};
#     uint32_t deviceState = 0;
# };

# struct ResponseDeviceDiscovery : Response {
#     ResponseDeviceDiscovery() : Response(Command::DEVICE_DISCOVERY_EX) {}
#     char id[32] = {0};
#     uint32_t state = 0;
#     uint32_t protocol = 0;
#     uint32_t platform = 0;
#     uint32_t status = 0;
#     uint16_t portHttp = 0;
#     uint16_t portHttps = 0;
# };

class Command(Enum):
    DEVICE_DISCOVERY = 1
    DEVICE_DISCOVERY_EX = 4

class Platform(Enum):
    MYRIAD_X = 2
    KEEMBAY = 3

class Protocol(Enum):
    USB_VSC = 0
    USB_CDC = 1
    PCIE = 2
    IPC = 3
    TCP_IP = 4

class State(Enum):
    BOOTED = 1
    UNBOOTED = 2
    BOOTLOADER = 3
    FLASH_BOOTED = 4
    GATE = 5
    GATE_BOOTED = 6

class DeviceDiscovery(object):
    def __init__(self, serial, portHttp, portHttps, address='0.0.0.0', broadcast='255.255.255.255', port=DEFAULT_DEVICE_DISCOVERY_PORT):
        logging.info(f'Running discovery on {address}:{port}')
        # Prepare a socket
        sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
        sock.setsockopt(socket.SOL_SOCKET, socket.SO_BROADCAST, 1)
        sock.bind((address, port))

        self._socket = sock

        self._listener = ListenerThread(sock, serial, portHttp, portHttps)
        self._listener.start()

    def set_state(self, state):
        self._listener.state = state

    def set_state_cb(self, cb):
        self._listener.get_state_cb = cb

class ListenerThread(threading.Thread):
    """The Listener Thread grabs incoming packets, parses them and forwards them to the right listeners"""
    def __init__(self, socket, serial, portHttp, portHttps):
        super(ListenerThread, self).__init__(
                name='ListenerThread'
        )

        self.state = State.GATE
        self.get_state_cb = None

        # Exit on script exit
        self.daemon = True

        # Store instance data
        self._socket = socket
        self._serial = serial
        self._portHttp = portHttp
        self._portHttps = portHttps

    def _sendto(self, packet, addr_port):
        return self._socket.sendto(packet, addr_port)

    def _get_state(self):
        if self.get_state_cb is not None:
            return self.get_state_cb()
        return self.state

    def run(self):
        while True:
            try:
                data, addr_port = self._socket.recvfrom(1500)
                logging.debug(f'Received data: {data} from addr: {addr_port}')

                # Command is uint32_t
                if len(data) == 4:
                    cmd = struct.unpack('<I', data)[0]
                    logging.debug(f'Received command: {cmd}')
                    logging.debug(f'cmd ({cmd}) == Command.DEVICE_DISCOVERY ({Command.DEVICE_DISCOVERY.value})')
                    if cmd == Command.DEVICE_DISCOVERY.value:
                        logging.debug(f'Command is DEVICE_DISCOVERY')

                        # Respond with DEVICE_DISCOVERY_EX
                        discovery_ex_resp = struct.pack('<I32sIIIIHH', Command.DEVICE_DISCOVERY_EX.value, self._serial.encode('utf-8'), self._get_state().value, Protocol.TCP_IP.value, Platform.KEEMBAY.value, 0, self._portHttp, self._portHttps)
                        logging.debug(f'Sending back data: {discovery_ex_resp} to addr: {addr_port}')
                        self._sendto(discovery_ex_resp, addr_port)
            except Exception as e:
                logging.error(f'Exception in the discovery thread: {e}')
                pass

==> depthai_gate-0.0.20-py3-none-any.whl: depthai_gate/discovery.py <==
import socket
import threading
import time
import struct
import logging
from enum import Enum

DEFAULT_DEVICE_DISCOVERY_PORT = 11491

# struct ResponseDeviceDiscovery : Response {
#     ResponseDeviceDiscovery() : Response(Command::DEVICE_DISCOVERY) {}
#     char mxid[32] = {0};
#     uint32_t deviceState = 0;
# };

# struct ResponseDeviceDiscovery : Response {
#     ResponseDeviceDiscovery() : Response(Command::DEVICE_DISCOVERY_EX) {}
#     char id[32] = {0};
#     uint32_t state = 0;
#     uint32_t protocol = 0;
#     uint32_t platform = 0;
#     uint32_t status = 0;
#     uint16_t portHttp = 0;
#     uint16_t portHttps = 0;
# };

class Command(Enum):
    DEVICE_DISCOVERY = 1
    DEVICE_DISCOVERY_EX = 4

class Platform(Enum):
    MYRIAD_X = 2
    KEEMBAY = 3
    RVC4 = 4

class Protocol(Enum):
    USB_VSC = 0
    USB_CDC = 1
    PCIE = 2
    IPC = 3
    TCP_IP = 4

class State(Enum):
    BOOTED = 1
    UNBOOTED = 2
    BOOTLOADER = 3
    FLASH_BOOTED = 4
    GATE = 5
    GATE_BOOTED = 6

class DeviceDiscovery(object):
    def __init__(self, serial, portHttp, portHttps, platform: Platform, address='0.0.0.0', broadcast='255.255.255.255', port=DEFAULT_DEVICE_DISCOVERY_PORT):
        logging.info(f'Running discovery on {address}:{port}')
        # Prepare a socket
        sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
        sock.setsockopt(socket.SOL_SOCKET, socket.SO_BROADCAST, 1)
        sock.bind((address, port))

        self._socket = sock

        self._listener = ListenerThread(sock, serial, portHttp, portHttps, platform)
        self._listener.start()

    def set_state(self, state):
        self._listener.state = state

    def set_state_cb(self, cb):
        self._listener.get_state_cb = cb

class ListenerThread(threading.Thread):
    """The Listener Thread grabs incoming packets, parses them and forwards them to the right listeners"""
    def __init__(self, socket, serial, portHttp, portHttps, platform: Platform):
        super(ListenerThread, self).__init__(
                name='ListenerThread'
        )

        self.state = State.GATE
        self.get_state_cb = None
        self.platform = platform
        # Exit on script exit
        self.daemon = True

        # Store instance data
        self._socket = socket
        self._serial = serial
        self._portHttp = portHttp
        self._portHttps = portHttps

    def _sendto(self, packet, addr_port):
        return self._socket.sendto(packet, addr_port)

    def _get_state(self):
        if self.get_state_cb is not None:
            return self.get_state_cb()
        return self.state

    def run(self):
        while True:
            try:
                data, addr_port = self._socket.recvfrom(1500)
                logging.debug(f'Received data: {data} from addr: {addr_port}')

                # Command is uint32_t
                if len(data) == 4:
                    cmd = struct.unpack('<I', data)[0]
                    logging.debug(f'Received command: {cmd}')
                    logging.debug(f'cmd ({cmd}) == Command.DEVICE_DISCOVERY ({Command.DEVICE_DISCOVERY.value})')
                    if cmd == Command.DEVICE_DISCOVERY.value:
                        logging.debug(f'Command is DEVICE_DISCOVERY')

                        # Respond with DEVICE_DISCOVERY_EX
                        discovery_ex_resp = struct.pack('<I32sIIIIHH', Command.DEVICE_DISCOVERY_EX.value, self._serial.encode('utf-8'), self._get_state().value, Protocol.TCP_IP.value, self.platform.value, 0, self._portHttp, self._portHttps)
                        logging.debug(f'Sending back data: {discovery_ex_resp} to addr: {addr_port}')
                        self._sendto(discovery_ex_resp, addr_port)
            except Exception as e:
                logging.error(f'Exception in the discovery thread: {e}')
                pass
